#!/bin/sh

set -eu

GPG_KEY='GPG KEY ID HERE'
BOOT_DIRECTORY='/boot'      # source, no trailing /
EFI_DIRECTORY='/boot/EFI'   # target, no trailing /
KERNEL_PREFIX='vmlinuz-'
INITRD_PREFIX='initramfs-'

escape_for_sed() {
    printf '%s' "$1" | sed 's!/!\\/!g'
}

rm -rf tmp
mkdir tmp

TMP_GRUB_CFG=tmp/grub.cfg
TMP_KERNELS=tmp/kernels

: >"$TMP_KERNELS"
for x in "$BOOT_DIRECTORY/$KERNEL_PREFIX"*; do
    printf '%s\n' "$x" >>"$TMP_KERNELS"
done

# Generate GRUB config
grub-mkconfig -o "$TMP_GRUB_CFG"

cp "$TMP_GRUB_CFG" "$EFI_DIRECTORY/$(basename $TMP_GRUB_CFG)"
echo "signing grub.cfg"
gpg2 --default-key "$GPG_KEY" --detach-sign "$EFI_DIRECTORY/$(basename $TMP_GRUB_CFG)" 

for x in "$BOOT_DIRECTORY/$KERNEL_PREFIX"* "$BOOT_DIRECTORY/$INITRD_PREFIX"*; do
    name="$(basename "$x")"

    echo "signing '$x'"
    rm -f "$BOOT_DIRECTORY/$name.sig"
    gpg2 --default-key "$GPG_KEY" --detach-sign "$BOOT_DIRECTORY/$name"
done

rm -r tmp
